## pyneng-quiz

Вопросы по темам курса/книги Python для сетевых инженеров.

Вопросы можно использовать:

* как мини-задания сразу после изучения темы
* для проверки знаний, как тест

Очень полезно ответить на вопросы после прочтения соответствующей темы. Они
позволят вспомнить материал темы, а также попробовать на практике разные
аспекты работы с Python.

Установить модуль

```
pip install pyneng-quiz
```

После этого запуск вопросов выполняется из cli командой

```
pquiz
```

